@@ -1,10 +1,10 @@
-__version__ = "0.3.12"
+__version__ = "0.3.13"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(Not currently on any branch)'
+__git_branch__ = '(detached from v0.3.13)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '8b5bf79c0db5a3fdee6b2d74719df5fb03ed99e5'
-__git_head_subject__ = 'Finished release v0.3.12.'
+__git_head_hash__ = '815bc93ade5a398b156fac1654e4f44bbcd23107'
+__git_head_subject__ = 'Finished release v0.3.13.'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
